import { Server } from "socket.io";
import {TSocket} from "../utilities/Types";
import ZoneRepository from "../repositories/ZoneRepository";
import ZoneManager from "../ZoneManager";
import {Character, Zone} from "@prisma/client";

interface IZoneLoad {
    zoneId?: number;
}

/**
 * @TODO: Implement zone loading, check if zone id is given or else load current character zone
 *
 * Handle character zone load event
 * @param socket
 * @param io
 */
export default function (socket: TSocket, io: Server) {
    socket.on('character:zone:load', async (data: IZoneLoad) => {
        console.log(`---User ${socket.character?.id} has requested zone.`);

        const zone = await ZoneRepository.getById(1);

        if (!zone) {
            console.log(`---Zone not found.`);
            return;
        }

        socket.join(zone.name);

        ZoneManager.addCharacterToZone(zone.id, socket.character as Character);

        // const socketConnectionsInRoom = await io.in(zone.name).fetchSockets();
        // const characters = socketConnectionsInRoom.filter(socket => socket.id !== socket.id);

        // let other clients know of new character
        socket.to(zone.name).emit('character:zone:character_join', socket.character);

        // send over zone and characters
        io.in(zone.name).to(socket.id).emit('character:zone:load', {
            zone: zone,
            characters: ZoneManager.getCharactersInZone(zone.id),
        });
    });
}